@@ -286,6 +286,7 @@ AssociationFilterTypeDef = TypedDict(
             "LastExecutedBefore",
             "LastExecutedAfter",
             "AssociationName",
+            "ResourceGroupName",
         ],
         "value": str,
     },
@@ -431,6 +432,7 @@ _OptionalCreateAssociationBatchRequestEntryTypeDef = TypedDict(
         "MaxErrors": str,
         "MaxConcurrency": str,
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
+        "SyncCompliance": Literal["AUTO", "MANUAL"],
     },
     total=False,
 )
@@ -472,6 +474,7 @@ AssociationDescriptionTypeDef = TypedDict(
         "MaxErrors": str,
         "MaxConcurrency": str,
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
+        "SyncCompliance": Literal["AUTO", "MANUAL"],
     },
     total=False,
 )
@@ -2135,6 +2138,7 @@ AssociationVersionInfoTypeDef = TypedDict(
         "MaxErrors": str,
         "MaxConcurrency": str,
         "ComplianceSeverity": Literal["CRITICAL", "HIGH", "MEDIUM", "LOW", "UNSPECIFIED"],
+        "SyncCompliance": Literal["AUTO", "MANUAL"],
     },
     total=False,
 )
